@@ -15,7 +15,7 @@ __PACKAGE__->primary_key('recordingId');
 
 has 'creationDate' => (is => 'rw', isa => 'Int', required => 1);
 has 'data' => (is => 'rw', isa => 'Str');
-has 'facilitator' => (is => 'rw', isa => 'Int');
+has 'facilitator' => (is => 'rw', isa => 'Str');
 has 'keywords' => (is => 'rw', isa => 'Str');
 has 'meetingId' => (is => 'rw', isa => 'Int', required => 1);
 has 'open' => (is => 'rw', isa => 'Bool');
